To use:
1. create a venv: `python -m venv venv`
2. activate it: `.\venv\Scripts\activate` or `source venv/bin/activate`, depending on your OS
3. install the requirements: `pip install -r requirements.txt`
4. run the script: `python main.py`